@@ -12,7 +12,7 @@
 import logging
 import pathlib
 import re
-import subprocess
+import subprocess  # noqa: S404
 import typing
 
 import click
@@ -34,7 +34,7 @@ def run_command(
     command: CommandArgs,
     suppress_command_logging: bool = False,
     suppress_argument_logging: bool = False,
-    **kwargs: typing.Any
+    **kwargs: typing.Any,
 ) -> subprocess.CompletedProcess:
     """
     Run a system command using ``subprocess.run``.
@@ -42,7 +42,8 @@ def run_command(
     Args:
         command: List of command and arguments.
         suppress_command_logging: Suppress logging of command.
-        suppress_argument_logging: Suppress logging of subprocess run command arguments.
+        suppress_argument_logging: Suppress logging of subprocess run command
+                                   arguments.
         **kwargs: Optional arguments passed through to ``subprocess.run``.
 
     Returns:
@@ -54,12 +55,12 @@ def run_command(
         log.debug("command arguments, {0}".format(str(kwargs)))
     final_args = {
         **kwargs,
-        # always return text as string, not bytes
         **{
+            # always return text as string, not bytes
             "text": True,
         },
     }
-    result = subprocess.run(command, **final_args)
+    result = subprocess.run(command, **final_args)  # noqa: S603 S604
 
     log.debug("command return code, {0}".format(result.returncode))
     log.debug("command stdout, {0}".format(result.stdout))
@@ -99,5 +100,6 @@ def report_console_error(message: str) -> None:
         message: Message to be reported.
     """
     click.echo(
-        click.style("FAILED: {0}".format(message), bold=True, fg="red"), err=True
+        click.style("FAILED: {0}".format(message), bold=True, fg="red"),
+        err=True,
     )
