@@ -19,7 +19,14 @@ log = logging.getLogger(__name__)
 
 
 def _generate_snippets(venv_path: pathlib.Path) -> None:
-    behave_command = ["behave", "--snippets", "--tags", "@notimplemented", "features"]
+    behave_command = [
+        "behave",
+        "--snippets",
+        "--tags",
+        "@notimplemented",
+        "features",
+    ]
     behave_command[0] = command_path(venv_path, behave_command)
-    # ignore errors from the snippets command because it seems to always exit dirty
+    # ignore errors from the snippets command because it seems to always exit
+    # dirty
     run_command(behave_command)
