@@ -14,6 +14,7 @@ import tempfile
 from behave import given, then, when
 
 from build_harness._utility import run_command
+from build_harness.tools.git import DEFAULT_DEFAULT_BRANCH_NAME
 from tests.ci.support.repo import (
     FeatureDryrunTagOnHead,
     FeatureDryrunTags,
@@ -64,13 +65,18 @@ def step_impl(context):
 
         create_venv(working_venv)
         _install_working_build_harness(working_venvbin)
+        print(f"working dir, {this_dir}")
+        print(f"cwd before chdir, {os.getcwd()}")
         with chdir_project_dir(working_dir):
-            assert os.getcwd() == str(working_dir)
+            print(f"cwd after chdir, {os.getcwd()}")
 
             work_release_flow = working_venvbin / "release-flow"
             this_command = [str(work_release_flow)] + context.given_arguments
             result = run_command(
-                this_command, capture_output=True, text=True, universal_newlines=True
+                this_command,
+                capture_output=True,
+                text=True,
+                universal_newlines=True,
             )
 
             print("result.stdout: {0}".format(result.stdout))
@@ -95,6 +101,7 @@ def step_impl(context):
 
 @then("emits a bad tag error to stderr")
 def step_impl(context):
+    print(f"tag error stderr: {context.run_result.stderr}")
     assert "Tags must be PEP-440 compliant" in context.run_result.stderr
 
 
@@ -108,16 +115,25 @@ def step_impl(context):
 
 @when("release flow extracts the tag data")
 def step_impl(context):
-    with git_repo_context(context.create_repo, debug_install=DEBUG_INSTALL,) as (
+    with git_repo_context(
+        context.create_repo,
+        debug_install=DEBUG_INSTALL,
+        default_branch=DEFAULT_DEFAULT_BRANCH_NAME,
+    ) as (
         mock_repo,
         this_rf_command,
     ):
+        print(f"repo dir, {mock_repo}")
+        print(f"cwd before chdir, {os.getcwd()}")
         with chdir_project_dir(mock_repo):
-            assert os.getcwd() == str(mock_repo)
+            print(f"cwd after chdir, {os.getcwd()}")
 
             this_command = [str(this_rf_command)] + context.given_arguments
             result = run_command(
-                this_command, capture_output=True, text=True, universal_newlines=True
+                this_command,
+                capture_output=True,
+                text=True,
+                universal_newlines=True,
             )
 
             print("result.stdout: {0}".format(result.stdout))
@@ -129,6 +145,10 @@ def step_impl(context):
 
 @then("the utility emits the constructed package version to stdout")
 def step_impl(context):
+    print(
+        "package version (actual, expected): "
+        f"{context.run_result.stdout}, {context.expected_version}"
+    )
     assert context.run_result.stdout == context.expected_version
 
 
