@@ -31,7 +31,8 @@ class TestApplyFormatting:
         mock_result = mocker.MagicMock()
         mock_result.returncode = 0
         mocker.patch(
-            "build_harness.commands.code_style.run_command", return_value=mock_result
+            "build_harness.commands.code_style.run_command",
+            return_value=mock_result,
         )
 
         _apply_formatting(MOCK_VENV_PATH)
@@ -41,11 +42,13 @@ class TestApplyFormatting:
         mock_results[0].returncode = 0
         mock_results[1].returncode = 1
         mocker.patch(
-            "build_harness.commands.code_style.run_command", side_effect=mock_results
+            "build_harness.commands.code_style.run_command",
+            side_effect=mock_results,
         )
 
         with pytest.raises(
-            FormattingError, match=r"^isort and/or black failed during formatting."
+            FormattingError,
+            match=r"^isort and/or black failed during formatting.",
         ):
             _apply_formatting(MOCK_VENV_PATH)
 
@@ -54,11 +57,13 @@ class TestApplyFormatting:
         mock_results[0].returncode = 1
         mock_results[1].returncode = 0
         mocker.patch(
-            "build_harness.commands.code_style.run_command", side_effect=mock_results
+            "build_harness.commands.code_style.run_command",
+            side_effect=mock_results,
         )
 
         with pytest.raises(
-            FormattingError, match=r"^isort and/or black failed during formatting."
+            FormattingError,
+            match=r"^isort and/or black failed during formatting.",
         ):
             _apply_formatting(MOCK_VENV_PATH)
 
@@ -68,7 +73,8 @@ class TestCheckFormatting:
         mock_result = mocker.MagicMock()
         mock_result.returncode = 0
         mocker.patch(
-            "build_harness.commands.code_style.run_command", return_value=mock_result
+            "build_harness.commands.code_style.run_command",
+            return_value=mock_result,
         )
 
         _check_formatting(MOCK_VENV_PATH)
@@ -78,7 +84,8 @@ class TestCheckFormatting:
         mock_results[0].returncode = 0
         mock_results[1].returncode = 1
         mocker.patch(
-            "build_harness.commands.code_style.run_command", side_effect=mock_results
+            "build_harness.commands.code_style.run_command",
+            side_effect=mock_results,
         )
 
         with pytest.raises(BlackCheckError, match=r"^black check failed"):
@@ -89,7 +96,8 @@ class TestCheckFormatting:
         mock_results[0].returncode = 1
         mock_results[1].returncode = 0
         mocker.patch(
-            "build_harness.commands.code_style.run_command", side_effect=mock_results
+            "build_harness.commands.code_style.run_command",
+            side_effect=mock_results,
         )
 
         with pytest.raises(IsortCheckError, match=r"^isort check failed"):
@@ -122,13 +130,16 @@ class TestFormatting:
                         ".",
                     ]
                 ),
-                mocker.call(["/some/test_code_style_formatting_clean/path/black", "."]),
+                mocker.call(
+                    ["/some/test_code_style_formatting_clean/path/black", "."]
+                ),
             ]
         )
 
     def test_unknown_error(self, click_runner, mocker):
         mocker.patch(
-            "build_harness.commands.code_style.run_command", side_effect=RuntimeError()
+            "build_harness.commands.code_style.run_command",
+            side_effect=RuntimeError(),
         )
         result = click_runner.invoke(main, ["formatting"])
 
@@ -177,7 +188,8 @@ class TestCheckArgument:
 
     def test_check_unknown_error(self, click_runner, mocker):
         mocker.patch(
-            "build_harness.commands.code_style.run_command", side_effect=RuntimeError()
+            "build_harness.commands.code_style.run_command",
+            side_effect=RuntimeError(),
         )
         result = click_runner.invoke(main, ["formatting", "--check"])
 
