@@ -87,7 +87,8 @@ pkg3                       2020.6.20
         )
 
         mocker.patch(
-            "build_harness.commands.dependencies.run_command", return_value=mock_result
+            "build_harness.commands.dependencies.run_command",
+            return_value=mock_result,
         )
 
         _check_dependencies(MOCK_VENV_BIN_PATH, mock_dependencies, "all")
@@ -105,7 +106,8 @@ Package                       Version
         )
 
         mocker.patch(
-            "build_harness.commands.dependencies.run_command", return_value=mock_result
+            "build_harness.commands.dependencies.run_command",
+            return_value=mock_result,
         )
 
         with pytest.raises(
@@ -129,7 +131,8 @@ pkg3                       2020.6.20
         )
 
         mocker.patch(
-            "build_harness.commands.dependencies.run_command", return_value=mock_result
+            "build_harness.commands.dependencies.run_command",
+            return_value=mock_result,
         )
 
         with pytest.raises(
@@ -153,7 +156,8 @@ pkg3                       2020.6.20
         )
 
         mocker.patch(
-            "build_harness.commands.dependencies.run_command", return_value=mock_result
+            "build_harness.commands.dependencies.run_command",
+            return_value=mock_result,
         )
 
         with pytest.raises(
@@ -175,7 +179,8 @@ Package                       Version
         )
 
         mocker.patch(
-            "build_harness.commands.dependencies.run_command", return_value=mock_result
+            "build_harness.commands.dependencies.run_command",
+            return_value=mock_result,
         )
 
         _check_dependencies(MOCK_VENV_BIN_PATH, mock_dependencies, "all")
@@ -188,7 +193,8 @@ Package                       Version
         )
 
         mocker.patch(
-            "build_harness.commands.dependencies.run_command", return_value=mock_result
+            "build_harness.commands.dependencies.run_command",
+            return_value=mock_result,
         )
 
         with pytest.raises(
@@ -256,10 +262,13 @@ some status
 command failed
 """
         mocker.patch(
-            "build_harness.commands.dependencies.run_command", return_value=mock_result
+            "build_harness.commands.dependencies.run_command",
+            return_value=mock_result,
         )
 
-        with pytest.raises(VenvError, match=r"^Failed creating virtual environment"):
+        with pytest.raises(
+            VenvError, match=r"^Failed creating virtual environment"
+        ):
             _check_virtual_environment(MOCK_VENV_BIN_PATH)
 
     def test_bad_venv_bin_raises(self, mocker, mock_venv_create):
@@ -280,7 +289,9 @@ class TestInstallProjectDependencies:
             "toml == 3.1.4",
             "flit >=2.0,<4",
         ]
-        mock_command = mocker.patch("build_harness.commands.dependencies.run_command")
+        mock_command = mocker.patch(
+            "build_harness.commands.dependencies.run_command"
+        )
         mock_command.return_value.returncode = 0
 
         _install_project_dependencies(mock_dependencies, MOCK_VENV_BIN_PATH)
@@ -304,7 +315,9 @@ class TestInstallProjectDependencies:
             "toml == 3.1.4",
             "flit >=2.0,<4",
         ]
-        mock_command = mocker.patch("build_harness.commands.dependencies.run_command")
+        mock_command = mocker.patch(
+            "build_harness.commands.dependencies.run_command"
+        )
         mock_command.return_value.returncode = 1
 
         with pytest.raises(
@@ -405,7 +418,12 @@ class TestInstall:
         mock_run.assert_has_calls(
             [
                 mocker.call(
-                    [str(MOCK_VENV_BIN_PATH / "pip"), "install", "-r", "/dev/stdin"],
+                    [
+                        str(MOCK_VENV_BIN_PATH / "pip"),
+                        "install",
+                        "-r",
+                        "/dev/stdin",
+                    ],
                     capture_output=True,
                     input="requests == 3.1.4\nbehave == 1.2.6\nsphinx == "
                     "3.2.1\npytest == 6.1.1",
@@ -432,7 +450,12 @@ class TestInstall:
         mock_run.assert_has_calls(
             [
                 mocker.call(
-                    [str(MOCK_VENV_BIN_PATH / "pip"), "install", "-r", "/dev/stdin"],
+                    [
+                        str(MOCK_VENV_BIN_PATH / "pip"),
+                        "install",
+                        "-r",
+                        "/dev/stdin",
+                    ],
                     capture_output=True,
                     input="requests == 3.1.4\nbehave == 1.2.6\nsphinx == 3.2.1\npytest == 6.1.1",
                     text=True,
@@ -582,7 +605,9 @@ class TestInstall:
 
         mocker.patch(
             "build_harness.commands.dependencies._install_project_dependencies",
-            side_effect=DependencyInstallError("Dependency installation failed"),
+            side_effect=DependencyInstallError(
+                "Dependency installation failed"
+            ),
         )
         result = click_runner.invoke(main, ["install"])
 
@@ -642,4 +667,7 @@ pytest   6.1.1
         result = click_runner.invoke(main, ["install", "--check"])
 
         assert result.exit_code == ExitState.DEPENDENCY_CHECK_FAILED.value
-        assert "Failed to list installed virtual environment packages" in result.output
+        assert (
+            "Failed to list installed virtual environment packages"
+            in result.output
+        )
