@@ -170,7 +170,7 @@ class TestPublish:
             result = click_runner.invoke(
                 main,
                 [
-                    "--log-enable-console",
+                    "--log-console-enable",
                     "--log-level",
                     "debug",
                     "publish",
@@ -292,7 +292,7 @@ class TestPublish:
             result = click_runner.invoke(
                 main,
                 [
-                    "--log-enable-console",
+                    "--log-console-enable",
                     "--log-level",
                     "debug",
                     "publish",
