@@ -14,4 +14,6 @@ import build_harness.commands.build_harness_group
 
 @pytest.fixture
 def mock_sysargv():
-    build_harness.commands.build_harness_group.sys.argv = ["/some/path/build-harness"]
+    build_harness.commands.build_harness_group.sys.argv = [
+        "/some/conftest/path/build-harness"
+    ]
